import { SensorsService } from '@business/services/http/sensors.service';
import { OrganizationService } from '@business/services/http/organization.service';
import { MonitorPointService } from '@business/services/http/monitor-point.service';
import { VersionService } from '@business/services/http/version.service';
import { AreacodeService } from '@business/services/http/areacode.service';
import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { BasicInfoComponent } from './basic-info/basic-info.component';
import { VersionComponent } from './version/version.component';
import { MonitorPointComponent } from './monitor-point/monitor-point.component';
import {RouterModule, Routes} from '@angular/router';
import { SharedModule } from '@shared/shared.module';
import { Version } from '@angular/compiler/src/util';
import { _HttpClient } from '@delon/theme/services/http/http.client';
import { PipeModule } from '@business/pipe/pipe.module';
import { FormBuilder } from '@angular/forms';
import { VersionEditComponent } from './version/version-edit/version-edit.component';
import { MonitorPointEditComponent } from './monitor-point/monitor-point-edit/monitor-point-edit.component';
import { VersionSensorConfigComponent } from './version/version-sensor-config/version-sensor-config.component';

const COMPONENTS_NOROUNT = [  VersionEditComponent, MonitorPointEditComponent, VersionSensorConfigComponent  ];

const routes: Routes = [
  {
    path: '',
    children: [
      { path: 'basic', component: BasicInfoComponent },
      { path: 'version', component: VersionComponent },
      { path: 'monitor-point', component: MonitorPointComponent }
    ]
  }
];

@NgModule({
  imports: [
    // 管道模块必须当前模块导入
    PipeModule,
    CommonModule,
    SharedModule,
    RouterModule.forChild(routes)
  ],
  declarations: [
    BasicInfoComponent,
    VersionComponent,
    MonitorPointComponent,
    ...COMPONENTS_NOROUNT     
  ],
  providers: [OrganizationService, VersionService, 
    SensorsService, AreacodeService, MonitorPointService,
    _HttpClient, FormBuilder],
  entryComponents: COMPONENTS_NOROUNT
})
export class DevicesModule { }
